@@ -11,6 +11,8 @@ import requests
 from flask import Blueprint, render_template
 from invenio_cache import current_cache
 
+from .search import FrontpageRecordsSearch
+
 
 def fetch_schemaorg_jsonld(doi_url):
     """Fetch the Schema.org metadata for the DOI."""
@@ -73,6 +75,11 @@ def create_blueprint(app):
 
         return metadata
 
+    @blueprint.route("/")
+    def tuw_index():
+        records = FrontpageRecordsSearch()[:5].sort("-created").execute()
+        return render_template("invenio_theme_tuw/frontpage.html", records=records_serializer(records))
+
     @blueprint.route("/tuw/policies")
     def tuw_policies():
         return render_template("invenio_theme_tuw/policies.html")
